/*
===========================================================

  Ghost API
  
===========================================================
*/

import axios from 'axios'

class Ghost {
  constructor(studioStore) {
    this.axios = axios
    this.studio = studioStore?.studio || { 
      ghost_base_url: 'https://ghost.wfdu.fm/ghost/api/v3/content'
    }

    this.ghost_base_url = 'https://ghost.wfdu.fm/ghost/api/v3/content'
    this.apiKey = 'b2c304494cc10d3e52164122fc' // Replace with your actual Content API key
  }

  /*
  -----------------------------------------------------------
  Routes
  -----------------------------------------------------------
  */

  g(path, query = null) {
    if (query) return `${this.ghost_base_url}${path}?key=${this.apiKey}${query}`
    return `${this.ghost_base_url}${path}?key=${this.apiKey}`
  }
  
  routes = {
    posts: query => this.g('/posts/', query),
    postById: id => this.g(`/posts/${id}/`),
    postBySlug: (slug, query) => this.g(`/posts/slug/${slug}/`),
    authors: () => this.g('/authors/'),
    authorById: id => this.g(`/authors/${id}/`),
    authorBySlug: slug => this.g(`/authors/slug/${slug}/`),
    tags: () => this.g('/tags/'),
    tagById: id => this.g(`/tags/${id}/`),
    tagBySlug: slug => this.g(`/tags/slug/${slug}/`),
    pages: () => this.g('/pages/'),
    pageById: id => this.g(`/pages/${id}/`),
    pageBySlug: slug => this.g(`/pages/slug/${slug}/`),
    tiers: () => this.g('/tiers/'),
    settings: () => this.g('/settings/')
  }

  buildURL(type, id = null) {
    const url = this.routes[type](id)

    return url 
  }

  /*
  -----------------------------------------------------------
    Get from Ghost API
  -----------------------------------------------------------
  */

  async getPath(path) {
    let response = null
    let url = path.includes(this.studio.ghost_base_url) ? path : this.studio.ghost_base_url + path

    try {
      response = await this.axios.get(url)
    } catch(error) {
      console.error('Error fetching from Ghost API:', url, error.message)
      console.error(error.response?.data)
    }

    return response?.data
  }

  async get(type, id = null) {
    const url = this.buildURL(type, id)
    return await this.getPath(url)
  }
}

/*
-----------------------------------------------------------
  Export
-----------------------------------------------------------
*/

export default Ghost