// https://nuxt.com/docs/api/configuration/nuxt-config

import path from 'path'

if(global){
  global.X = console.log
}
if(typeof window != 'undefined'){
  window.X = console.log
}


require('dotenv').config()

// console.log('process.env.STUDIO_WEBSITE_TOOLKIT_PATH:')
// console.log(process.env.STUDIO_WEBSITE_TOOLKIT_PATH)

// console.log('__dirname:')
// console.log(__dirname)

export default defineNuxtConfig({

  app: {
    head: {
      title: 'KWMR',
      htmlAttrs: {
        lang: 'en'
      },
      meta: [
        { charset: 'utf-8' },
        { name: 'viewport', content: 'width=device-width, initial-scale=1' },
        { hid: 'description', name: 'description', content: '' },
        { name: 'format-detection', content: 'telephone=no' }
      ],
      link: [
        { rel: 'icon', type: 'image/x-icon', href: 'https://kwmr.org/wp-content/uploads/2015/01/KWMR_Favicon5.gif' },
        { rel: "stylesheet", href: "https://use.typekit.net/fon7gis.css" },
        { rel: "stylesheet", href: "https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css" },
      ],
      script: [
        // {
        //   src: "https://kwmr.kindful.com/embeds/c4571589-260a-4a56-9152-80435d37de7f/init.js?type=form",
        //   dataEmbedId: "c4571589-260a-4a56-9152-80435d37de7f", 
        //   dataLookupType: "jquery-selector", 
        //   dataLookupValue: "#kindful-donate-form-c4571589-260a-4a56-9152-80435d37de7f"
        // }
      ]
    },
  },

  modules: ['nuxt-gtag', "@nuxt/image"],

  gtag: {
    id: 'G-Y8HP46K88K'
  },

  routeRules: {
    "/donate": {
        redirect: {
          to: "https://kwmr.kindful.com/",
          statusCode: 302,
        },
    },
  },

  css: [
    '@/assets/sass/main.sass',
  ],

  hooks: {
    'app:error': (err) => {
      console.log('woooooop')
      console.log(err)
    },
    'vue:error': (err) => {
      console.log('woooooop')
      console.log(err)
    },
    'build:error': (err) => {
      console.log('woooooop')
      console.log(err)
    },
  },

  alias: {
    '~creek-website-toolkit': process.env.STUDIO_WEBSITE_TOOLKIT_PATH 
      || path.join(__dirname, '../studio-website-toolkit')
  },

  vite: {
    server: {
      fs: {
        allow: [
          process.env.STUDIO_WEBSITE_TOOLKIT_PATH 
            || path.join(__dirname, '../studio-website-toolkit')
        ],
      },
    },
    build: {
      rollupOptions: {
        external: [
          'vue/server-renderer',
        ]
      },
      minify: 'terser',
    },
    esbuild: {
      minifyWhitespace: true,
      minifySyntax: false,
      minifyIdentifiers: false,
    },
    css: {
      preprocessorOptions: {
        sass: {
          additionalData: '@use "~/assets/sass/_shared.sass" as *\n'
        }
      }
    }
  },

  nitro: {
    preset: 'node-server'
  },

  plugins: [
    '~/plugins/remote-config.js'
  ],

  runtimeConfig: {
    public: {
      remoteSettingsUrl: 'https://kwmr.studio.creek.org/api/v1/website/settings'
    }
  },

})