import { defineNuxtPlugin } from '#app'

export default defineNuxtPlugin(async (nuxtApp) => {
  const config = useRuntimeConfig()

  // Function to fetch remote settings
  const fetchRemoteSettings = async () => {
    try {
      const response = await fetch(config.public.remoteSettingsUrl)
      const settings = await response.json()
      // console.log('Fetched settings:', settings)
      config.public.studio = settings
      // Merge the remote settings with the existing runtime config
      // Object.assign(config.public.studio, settings)
      // console.log('Updated config.public:', config.public)
    } catch (error) {
      // console.error('Failed to fetch remote settings:', error)
    }
  }

  // Fetch settings on initial load
  await fetchRemoteSettings()

  // Set up periodic refresh
  if (process.server) {
    // On the server, we'll use a simple timeout loop
    const refreshLoop = async () => {
      await new Promise(resolve => setTimeout(resolve, 60000)) // Wait for 1 minute
      await fetchRemoteSettings()
      refreshLoop() // Call the function again to create a loop
    }
    refreshLoop() // Start the loop
  } else {
    // On the client, we can use setInterval
    setInterval(fetchRemoteSettings, 60000) // Refresh every 1 minute
  }

  // Make the config available in the app
  nuxtApp.provide('remoteConfig', config.public)
})